==> SD35B_0.02.1_src.tar.gz: Sd35b/decoder/FileCtrl.h <==
/*
 * FileCtrl.h - "ALICE SOFT System3.x" compatible scenario decoder SD35
 *
 * Copyright (C) 1999 Atsushi Mizuguchi  All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 * 
 * 
 */

#ifndef __FileCtrl_h__
#define __FileCtrl_h__
/**********************************************************************
	ALSD FileController

	1999. 1	A.Mizuguchi
**********************************************************************/
#include "ScenarioDecoderSystem.h"
#include "MessageCtrl.h"
#include "SelectionCtrl.h"
//
namespace ALSD{
	class CFileCtrl;
}

//
namespace ALSD_FILECTR {
	const char *const   ALSD_SAVEDATA_TYPE		= "System3.5 SavaData(c)ALICE-SOFT";
	const unsigned long ALSD_SAVEDATA_VERSION	= 0x00350200;
	
	struct stWinInfo {
		short x, y, w, h;
	};
	struct stSaveHeader {
		char			Type[32];
		int				Version;
		char			GameName[28];
		unsigned char	selFontSize;
		unsigned char	selFontColor;
		unsigned char	selClearColor;
		unsigned char	selFrameColor;
		unsigned char	msgFontSize;
		unsigned char	msgFontColor;
		unsigned char	msgClearColor;
		unsigned char	msgFrameColor;
		unsigned char	reserve1_8[8];
		long			ScenarioPage;
		long			ScenarioIndex;
		unsigned char	reserve2_8[8];
		stWinInfo		selWinInfo[ALSD_SELCTR::InfoMax];
		stWinInfo		msgWinInfo[ALSD_MSGCTR::InfoMax];
		long			stackinfo;
		long			StringVar;
		unsigned char	reserve3_8[8];
		long			SystemVar[256];
		long			reserve4_228[228];
	};
};

//
// class 
class ALSD::CFileCtrl {
public:
	CFileCtrl( const char *_lpFileList, ALSD::CScenarioDecoder *_lpSD );
	virtual ~CFileCtrl();
	//
	const char *GetPath( void ){ return m_lpPath;};
	//
	long LoadData( CFileData *_lpData, FILEDATATYPE _Type, long _Page );
	long LoadData( CFileData **_lplpData, FILEDATATYPE _Type, long _Page );
	long CheckData( FILEDATATYPE _Type, long _Page ); // L10

	//
	long SaveData( const std::string &_strFileName, long *_lpMem, long _Count );
	long LoadData( const std::string &_strFileName, long *_lpMem, long _Count );
	long SaveDataString( const std::string &_strFileName, long _num, long _Count );
	long LoadDataString( const std::string &_strFileName, long _num, long _Count );
	long SaveDataAll( long _num );
	long LoadDataAll( long _num );
	long LoadDataPartial( long _num, long _Page, long _Index, long _Count );
protected:
	//
	CScenarioDecoder *m_lpSD;
	//
	long Create( const char *_lpFileList );
	long Destroy( void );
	
	// t@C
	CFileAld	*m_lpAld[ALSD_ALDTYPE_MAX][ALSD_ALDFILE_MAX];
	char		 m_lpPath[256];
	char		 m_lpCoreName[256]; // "xxxxxSA.ALD"
private:
};


#endif

==> SD35B_0.02.2_src.tar.gz: Sd35b/decoder/FileCtrl.h <==
/*
 * FileCtrl.h - "ALICE SOFT System3.x" compatible scenario decoder SD35
 *
 * Copyright (C) 1999 Atsushi Mizuguchi  All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 * 
 * 
 */

#ifndef __FileCtrl_h__
#define __FileCtrl_h__
/**********************************************************************
	ALSD FileController

	1999. 1	A.Mizuguchi
**********************************************************************/
#include "ScenarioDecoderSystem.h"
#include "MessageCtrl.h"
#include "SelectionCtrl.h"
//
namespace ALSD{
	class CFileCtrl;
}

//
namespace ALSD_FILECTR {
	const char *const   ALSD_SAVEDATA_TYPE		= "System3.5 SavaData(c)ALICE-SOFT";
	const unsigned long ALSD_SAVEDATA_VERSION	= 0x00350200;
	
	struct stWinInfo {
		short x, y, w, h;
	};
	struct stSaveHeader {
		char			Type[32];
		int				Version;
		char			GameName[28];
		unsigned char	selFontSize;
		unsigned char	selFontColor;
		unsigned char	selClearColor;
		unsigned char	selFrameColor;
		unsigned char	msgFontSize;
		unsigned char	msgFontColor;
		unsigned char	msgClearColor;
		unsigned char	msgFrameColor;
		unsigned char	reserve1_8[8];
		long			ScenarioPage;
		long			ScenarioIndex;
		unsigned char	reserve2_8[8];
		stWinInfo		selWinInfo[ALSD_SELCTR::InfoMax];
		stWinInfo		msgWinInfo[ALSD_MSGCTR::InfoMax];
		long			stackinfo;
		long			StringVar;
		unsigned char	reserve3_8[8];
		long			SystemVar[256];
		long			reserve4_228[228];
	};
};

//
// class 
class ALSD::CFileCtrl {
public:
	CFileCtrl( const char *_lpFileList, ALSD::CScenarioDecoder *_lpSD );
	virtual ~CFileCtrl();
	//
	const char *GetPath( void ){ return m_lpPath;};
	//
	long LoadData( CFileData *_lpData, FILEDATATYPE _Type, long _Page );
	long LoadData( CFileData **_lplpData, FILEDATATYPE _Type, long _Page );
	long CheckData( FILEDATATYPE _Type, long _Page ); // L10

	//
	long CopyData( long _dst, long _src );

	long SaveData( const std::string &_strFileName, long *_lpMem, long _Count );
	long LoadData( const std::string &_strFileName, long *_lpMem, long _Count );

	long SaveDataString( const std::string &_strFileName, long _num, long _Count );
	long LoadDataString( const std::string &_strFileName, long _num, long _Count );
	
	long SaveDataAll( long _num );
	long LoadDataAll( long _num );

	long SaveDataPart( long _Num, long _Page, long _Index, long _Count );
	long LoadDataPart( long _Num, long _Page, long _Index, long _Count );
protected:
	//
	CScenarioDecoder *m_lpSD;
	//
	long Create( const char *_lpFileList );
	long Destroy( void );
	
	// t@C
	CFileAld	*m_lpAld[ALSD_ALDTYPE_MAX][ALSD_ALDFILE_MAX];
	char		 m_lpPath[256];
	char		 m_lpCoreName[256]; // "xxxxxSA.ALD"
private:
};


#endif
